#include <client.h>

/* This file handles various player related functions.  This includes
 * both things that operate on the player item, cpl structure, or
 * various commands that the player issues.
 *
 *  does most of the work for sending messages to the server
 *   Again, most of these appear self explanatory.  Most send a bunch of
 *   commands like apply, examine, fire, run, etc.  This looks like it
 *   was done by Mark to remove the old keypress stupidity I used. 
 */

/* This translates the numeric direction id's into the actual direction
 * commands.  This lets us send the actual command (ie, 'north'), which
 * makes handling on the server side easier.
 */

char *directions[9] = {"stay", "north", "northeast", "east", "southeast",
		"south","southwest", "west", "northwest"};


/*
 *  Initialiazes player item, information is received from server
 */
void new_player (long tag, char *name, long weight, long face)
{
    cpl.ob->tag    = tag;
    cpl.ob->nrof   = 1;
    copy_name (cpl.ob->name, name);
    cpl.ob->weight = (float) weight / 1000;
    cpl.ob->face   = face;
}


void client_send_apply (int tag)
{
    char buf[MAX_BUF];

    sprintf(buf,"apply %d", tag);
    cs_write_string(csocket.fd, buf, strlen(buf));
}

void client_send_examine (int tag)
{
    char buf[MAX_BUF];

    sprintf(buf,"examine %d", tag);
    cs_write_string(csocket.fd, buf, strlen(buf));

}

/* Requests nrof objects of tag get moved to loc. */
void client_send_move (int loc, int tag, int nrof)
{
    char buf[MAX_BUF];

    sprintf(buf,"move %d %d %d", loc, tag, nrof);
    cs_write_string(csocket.fd, buf, strlen(buf));
}



void move_player(int dir) {
    char buf[MAX_BUF];

    sprintf(buf,"command %s", directions[dir]);
    cs_write_string(csocket.fd, buf, strlen(buf));
}

/* Fires in a specified direction.  Note that direction 0 is a valid
 * case - the fire is centered on the player.
 */


void stop_fire()
{
    cs_write_string(csocket.fd, "command fire_stop", strlen("command fire_stop"));
}

void stop_run()
{
    cs_write_string(csocket.fd, "command run_stop", strlen("command run_stop"));
}

void fire_dir(int dir) {
    char buf[MAX_BUF];

    sprintf(buf,"command fire %d", dir);
    cs_write_string(csocket.fd, buf, strlen(buf));
}

void run_dir(int dir) {
    char buf[MAX_BUF];

    sprintf(buf,"command run %d", dir);
    cs_write_string(csocket.fd, buf, strlen(buf));
}


void send_command(char *command) {
    char buf[MAX_BUF];

    sprintf(buf,"command %d %s", cpl.count,command);
    cs_write_string(csocket.fd, buf, strlen(buf));
    cpl.count=0;
}

/* This is an extended command (ie, 'who, 'whatever, etc).  In general,
 * we just send the command to the server, but there are a few that
 * we care about (bind, unbind)
 */

void extended_command(char *command) {
    char *cp = command, *cpnext;

    if ((cpnext = strchr(cp, ' '))!=NULL)
	*cpnext++ = '\0';


    if (!strcmp(cp, "bind"))
	bind_key(cpnext);
    else if (!strcmp(cp,"unbind"))
	unbind_key(cpnext);
    else if (!strcmp(cp,"showicons"))
	set_show_icon (cpnext);
    else if (!strcmp(cp,"showweight"))
	set_show_weight (cpnext);
    else if (!strcmp(cp,"scroll"))
	set_scroll(cpnext);
    else if (!strcmp(cp,"inv")) /* inventory command is sended to server
				   for debugging purposes */
	print_inventory (cpl.ob);
    else {
	char buf[MAX_BUF];

	/* reconstruct the string */
	if (cpnext) *(--cpnext) = ' ';


	sprintf(buf,"command %s", command);
	cs_write_string(csocket.fd, buf, strlen(buf));
    }
}
 
